==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/lt_LT.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nepavyko nusiųsti el. pašto šiems naudotojams: %s ",
    "Preparing update" : "Ruošiamasi atnaujinimui",
    "Turned on maintenance mode" : "Įjungta priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta priežiūros veiksena",
    "Maintenance mode is kept active" : "Priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Checked database schema update" : "Tikrinama duomenų bazės struktūra",
    "Checked database schema update for apps" : "Tikrinama duomenų bazės struktūra įskiepiams",
    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
    "Repair warning: " : "Taisymo perspėjimas:",
    "Repair error: " : "Taisymo klaida:",
    "Following apps have been disabled: %s" : "Išjungti įskiepiai: %s",
    "Already up to date" : "Jau naujausia",
    "File is too big" : "Per didelis failas",
    "Invalid file provided" : "Netinkamas failas",
    "No image or file provided" : "Nenurodytas paveikslėlis ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslėlis",
    "No temporary profile picture available, try again" : "Nėra laikino profilio paveikslėlio, bandykite dar kartą",
    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
    "%s password reset" : "%s slaptažodžio atnaujinimas",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atkūrimo laiško, susisiekite su administratoriumi.",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sk.",
    "Mon." : "Pr.",
    "Tue." : "An.",
    "Wed." : "Tr.",
    "Thu." : "Kt.",
    "Fri." : "Pn.",
    "Sat." : "Št.",
    "Su" : "S",
    "Mo" : "P",
    "Tu" : "A",
    "We" : "T",
    "Th" : "K",
    "Fr" : "Pn",
    "Sa" : "Š",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rugp.",
    "Sep." : "Rugs.",
    "Oct." : "Spa.",
    "Nov." : "Lap.",
    "Dec." : "Groud.",
    "Settings" : "Nustatymai",
    "Saving..." : "Saugoma...",
    "seconds ago" : "prieš sekundę",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas, susisiekite su administratoriumi.",
    "No" : "Ne",
    "Yes" : "Taip",
    "Choose" : "Pasirinkite",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "Ok" : "Gerai",
    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failas konfliktuoja","{count} failai konfliktuoja","{count} failų konfliktų"],
    "One file conflict" : "Vienas failo konfliktas",
    "New Files" : "Naujas failas",
    "Already existing files" : "Egzistuojantys failai",
    "Which files do you want to keep?" : "Kuriuos failus norite laikyti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasirenkate abi versijas, nukopijuotas failas turės pridėtą numerį pavadinime.",
    "Cancel" : "Atšaukti",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant esančių failų ruošinį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Shared" : "Dalinamasi",
    "Error" : "Klaida",
    "Error while sharing" : "Klaida, dalijimosi metu",
    "Error while unsharing" : "Klaida, kai atšaukiamas dalijimasis",
    "Error setting expiration date" : "Klaida nustatant galiojimo laiką",
    "The public link will expire no later than {days} days after it is created" : "Vieša nuoroda galios ne mažiau kaip {days} dienas nuo sukūrimo",
    "Set expiration date" : "Nustatykite galiojimo laiką",
    "Expiration" : "Galiojimo laikas",
    "Expiration date" : "Galiojimo laikas",
    "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
    "Sending ..." : "Siunčiama...",
    "Email sent" : "Laiškas išsiųstas",
    "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
    "Share link" : "Dalintis nuoroda",
    "Link" : "Nuoroda",
    "Password protect" : "Apsaugotas slaptažodžiu",
    "Password" : "Slaptažodis",
    "Allow editing" : "Leisti redaguoti",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "Shared with you and the group {group} by {owner}" : "Pasidalino su Jumis ir {group} grupe {owner}",
    "Shared with you by {owner}" : "Pasidalino su Jumis {owner}",
    "group" : "grupė",
    "remote" : "nutolęs",
    "notify by email" : "pranešti el. paštu",
    "Unshare" : "Nebesidalinti",
    "can share" : "gali dalintis",
    "can edit" : "gali redaguoti",
    "create" : "sukurti",
    "change" : "keisti",
    "delete" : "ištrinti",
    "access control" : "priėjimo kontrolė",
    "An error occured. Please try again" : "Klaida, prašau bandyti dar kartą.",
    "Share" : "Dalintis",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dalintis su vartotoju kitame ownCloud debesyje, sintaksė vartotojas@example.com/owncloud",
    "Share with users or groups …" : "Dalintis su vartotoju ar grupe",
    "Share with users, groups or remote users …" : "Dalintis su vartotoju, grupe, ar nutolusiu vartotoju...",
    "Warning" : "Įspėjimas",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "The object type is not specified." : "Objekto tipas nenurodytas.",
    "Enter new" : "Įveskite naują",
    "Add" : "Pridėti",
    "Edit tags" : "Redaguoti žymes",
    "Error loading dialog template: {error}" : "Klaida įkeliant dialogo ruošinį: {error}",
    "No tags selected for deletion." : "Trynimui nepasirinkta jokia žymė.",
    "Hello world!" : "Sveikas pasauli!",
    "sunny" : "saulėta",
    "Please reload the page." : "Prašome perkrauti puslapį.",
    "The update was successful. Redirecting you to ownCloud now." : "Atnaujinimas buvo sėkmingas. Nukreipiame į jūsų ownCloud.",
    "Personal" : "Asmeniniai",
    "Users" : "Vartotojai",
    "Apps" : "Programos",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Error loading tags" : "Klaida įkeliant žymes",
    "Tag already exists" : "Žymė jau egzistuoja",
    "Error deleting tag(s)" : "Klaida trinant žymę(-es)",
    "Error tagging" : "Klaida pridedant žymę",
    "Error untagging" : "Klaida šalinant žymę",
    "Error favoriting" : "Klaida įtraukiant į mėgstamus.",
    "Error unfavoriting" : "Klaida pašalinant iš mėgstamų.",
    "Access forbidden" : "Priėjimas draudžiamas",
    "File not found" : "Failas nerastas",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Labas,\n\nInformuojame, kad %s pasidalino su Jumis %s.\nPažiūrėti tai: %s\n",
    "The share will expire on %s." : "Bendrinimo laikas baigsis %s.",
    "Cheers!" : "Sveikinimai!",
    "Internal Server Error" : "Vidinė serverio klaida",
    "Technical details" : "Techniniai duomenys",
    "Trace" : "Sekti",
    "Security warning" : "Saugumo perspėjimas",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų failai yra tikriausiai prieinami per internetą nes .htaccess failas neveikia.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Kad gauti informaciją apie tai kaip tinkamai sukonfigūruoti savo serverį, prašome skaityti <a href=\"%s\" target=\"_blank\">dokumentaciją</a>.",
    "Create an <strong>admin account</strong>" : "Sukurti <strong>administratoriaus paskyrą</strong>",
    "Username" : "Prisijungimo vardas",
    "Data folder" : "Duomenų katalogas",
    "Configure the database" : "Nustatyti duomenų bazę",
    "Database user" : "Duomenų bazės vartotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "Finish setup" : "Baigti diegimą",
    "Finishing …" : "Baigiama ...",
    "Log out" : "Atsijungti",
    "Search" : "Ieškoti",
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Kreipkitės į savo sistemos administratorių.",
    "Log in" : "Prisijungti",
    "Alternative Logins" : "Alternatyvūs prisijungimai",
    "Use the following link to reset your password: {link}" : "Slaptažodio atkūrimui naudokite šią nuorodą: {link}",
    "New password" : "Naujas slaptažodis",
    "New Password" : "Naujas slaptažodis",
    "Reset password" : "Atkurti slaptažodį",
    "This ownCloud instance is currently in single user mode." : "Ši ownCloud sistema yra vieno naudotojo veiksenoje.",
    "This means only administrators can use the instance." : "Tai reiškia, kad tik administratorius gali naudotis sistema.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
    "Thank you for your patience." : "Dėkojame už jūsų kantrumą."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/lt_LT.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nepavyko nusiųsti el. pašto šiems naudotojams: %s ",
    "Preparing update" : "Ruošiamasi atnaujinimui",
    "Turned on maintenance mode" : "Įjungta priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta priežiūros veiksena",
    "Maintenance mode is kept active" : "Priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Checked database schema update" : "Tikrinama duomenų bazės struktūra",
    "Checked database schema update for apps" : "Tikrinama duomenų bazės struktūra įskiepiams",
    "Updated \"%s\" to %s" : "Atnaujinta \"%s\" į %s",
    "Repair warning: " : "Taisymo perspėjimas:",
    "Repair error: " : "Taisymo klaida:",
    "Following apps have been disabled: %s" : "Išjungti įskiepiai: %s",
    "Already up to date" : "Jau naujausia",
    "File is too big" : "Per didelis failas",
    "Invalid file provided" : "Netinkamas failas",
    "No image or file provided" : "Nenurodytas paveikslėlis ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Netinkamas paveikslėlis",
    "No temporary profile picture available, try again" : "Nėra laikino profilio paveikslėlio, bandykite dar kartą",
    "No crop data provided" : "Nenurodyti apkirpimo duomenys",
    "%s password reset" : "%s slaptažodžio atnaujinimas",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atkūrimo laiško, susisiekite su administratoriumi.",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sk.",
    "Mon." : "Pr.",
    "Tue." : "An.",
    "Wed." : "Tr.",
    "Thu." : "Kt.",
    "Fri." : "Pn.",
    "Sat." : "Št.",
    "Su" : "S",
    "Mo" : "P",
    "Tu" : "A",
    "We" : "T",
    "Th" : "K",
    "Fr" : "Pn",
    "Sa" : "Š",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rugp.",
    "Sep." : "Rugs.",
    "Oct." : "Spa.",
    "Nov." : "Lap.",
    "Dec." : "Groud.",
    "Settings" : "Nustatymai",
    "Saving..." : "Saugoma...",
    "seconds ago" : "prieš sekundę",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas, susisiekite su administratoriumi.",
    "No" : "Ne",
    "Yes" : "Taip",
    "Choose" : "Pasirinkite",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "Ok" : "Gerai",
    "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failas konfliktuoja","{count} failai konfliktuoja","{count} failų konfliktų"],
    "One file conflict" : "Vienas failo konfliktas",
    "New Files" : "Naujas failas",
    "Already existing files" : "Egzistuojantys failai",
    "Which files do you want to keep?" : "Kuriuos failus norite laikyti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasirenkate abi versijas, nukopijuotas failas turės pridėtą numerį pavadinime.",
    "Cancel" : "Atšaukti",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant esančių failų ruošinį",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "Shared" : "Dalinamasi",
    "Error" : "Klaida",
    "Error while sharing" : "Klaida, dalijimosi metu",
    "Error while unsharing" : "Klaida, kai atšaukiamas dalijimasis",
    "Error setting expiration date" : "Klaida nustatant galiojimo laiką",
    "The public link will expire no later than {days} days after it is created" : "Vieša nuoroda galios ne mažiau kaip {days} dienas nuo sukūrimo",
    "Set expiration date" : "Nustatykite galiojimo laiką",
    "Expiration" : "Galiojimo laikas",
    "Expiration date" : "Galiojimo laikas",
    "Choose a password for the public link" : "Viešos nuorodos slaptažodis",
    "Sending ..." : "Siunčiama...",
    "Email sent" : "Laiškas išsiųstas",
    "Resharing is not allowed" : "Dalijinasis išnaujo negalimas",
    "Share link" : "Dalintis nuoroda",
    "Link" : "Nuoroda",
    "Password protect" : "Apsaugotas slaptažodžiu",
    "Password" : "Slaptažodis",
    "Allow editing" : "Leisti redaguoti",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "Shared with you and the group {group} by {owner}" : "Pasidalino su Jumis ir {group} grupe {owner}",
    "Shared with you by {owner}" : "Pasidalino su Jumis {owner}",
    "group" : "grupė",
    "remote" : "nutolęs",
    "notify by email" : "pranešti el. paštu",
    "Unshare" : "Nebesidalinti",
    "can share" : "gali dalintis",
    "can edit" : "gali redaguoti",
    "create" : "sukurti",
    "change" : "keisti",
    "delete" : "ištrinti",
    "access control" : "priėjimo kontrolė",
    "An error occured. Please try again" : "Klaida, prašau bandyti dar kartą.",
    "Share" : "Dalintis",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dalintis su vartotoju kitame ownCloud debesyje, sintaksė vartotojas@example.com/owncloud",
    "Share with users or groups …" : "Dalintis su vartotoju ar grupe",
    "Share with users, groups or remote users …" : "Dalintis su vartotoju, grupe, ar nutolusiu vartotoju...",
    "Warning" : "Įspėjimas",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "The object type is not specified." : "Objekto tipas nenurodytas.",
    "Enter new" : "Įveskite naują",
    "Add" : "Pridėti",
    "Edit tags" : "Redaguoti žymes",
    "Error loading dialog template: {error}" : "Klaida įkeliant dialogo ruošinį: {error}",
    "No tags selected for deletion." : "Trynimui nepasirinkta jokia žymė.",
    "Hello world!" : "Sveikas pasauli!",
    "sunny" : "saulėta",
    "Please reload the page." : "Prašome perkrauti puslapį.",
    "The update was successful. Redirecting you to ownCloud now." : "Atnaujinimas buvo sėkmingas. Nukreipiame į jūsų ownCloud.",
    "Personal" : "Asmeniniai",
    "Users" : "Vartotojai",
    "Apps" : "Programos",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Error loading tags" : "Klaida įkeliant žymes",
    "Tag already exists" : "Žymė jau egzistuoja",
    "Error deleting tag(s)" : "Klaida trinant žymę(-es)",
    "Error tagging" : "Klaida pridedant žymę",
    "Error untagging" : "Klaida šalinant žymę",
    "Error favoriting" : "Klaida įtraukiant į mėgstamus.",
    "Error unfavoriting" : "Klaida pašalinant iš mėgstamų.",
    "Access forbidden" : "Priėjimas draudžiamas",
    "File not found" : "Failas nerastas",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Labas,\n\nInformuojame, kad %s pasidalino su Jumis %s.\nPažiūrėti tai: %s\n",
    "The share will expire on %s." : "Bendrinimo laikas baigsis %s.",
    "Cheers!" : "Sveikinimai!",
    "Internal Server Error" : "Vidinė serverio klaida",
    "Technical details" : "Techniniai duomenys",
    "Trace" : "Sekti",
    "Security warning" : "Saugumo perspėjimas",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų failai yra tikriausiai prieinami per internetą nes .htaccess failas neveikia.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Kad gauti informaciją apie tai kaip tinkamai sukonfigūruoti savo serverį, prašome skaityti <a href=\"%s\" target=\"_blank\">dokumentaciją</a>.",
    "Create an <strong>admin account</strong>" : "Sukurti <strong>administratoriaus paskyrą</strong>",
    "Username" : "Prisijungimo vardas",
    "Data folder" : "Duomenų katalogas",
    "Configure the database" : "Nustatyti duomenų bazę",
    "Database user" : "Duomenų bazės vartotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "Finish setup" : "Baigti diegimą",
    "Finishing …" : "Baigiama ...",
    "Log out" : "Atsijungti",
    "Search" : "Ieškoti",
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Kreipkitės į savo sistemos administratorių.",
    "Log in" : "Prisijungti",
    "Alternative Logins" : "Alternatyvūs prisijungimai",
    "Use the following link to reset your password: {link}" : "Slaptažodio atkūrimui naudokite šią nuorodą: {link}",
    "New password" : "Naujas slaptažodis",
    "New Password" : "Naujas slaptažodis",
    "Reset password" : "Atkurti slaptažodį",
    "This ownCloud instance is currently in single user mode." : "Ši ownCloud sistema yra vieno naudotojo veiksenoje.",
    "This means only administrators can use the instance." : "Tai reiškia, kad tik administratorius gali naudotis sistema.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi jei šis pranešimas nedingsta arba jei jis pasirodė netikėtai.",
    "Thank you for your patience." : "Dėkojame už jūsų kantrumą.",
    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
    "Password can not be changed. Please contact your administrator." : "Slaptažodis negali būti pakeistas, susisiekite su administratoriumi."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
